.. _combinatorics-permutations:

Permutations
============

.. module:: diofant.combinatorics.permutations

.. autoclass:: Permutation
   :members:

.. autoclass:: Cycle
   :members:

.. _combinatorics-generators:

.. autofunction:: _af_parity

Generators
----------

.. module:: diofant.combinatorics.generators

.. automethod:: diofant.combinatorics.generators.symmetric

.. automethod:: diofant.combinatorics.generators.cyclic

.. automethod:: diofant.combinatorics.generators.alternating

.. automethod:: diofant.combinatorics.generators.dihedral
